==> jc-1.4.0.tar.gz: polyglot/ext/jl/types/LazyClassInitializer__5fc.h <==
// public class polyglot.ext.jl.types.LazyClassInitializer_c

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c5e1cf6a6694b02b polyglot_ext_jl_types_LazyClassInitializer__5fc

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_jl_types_LazyClassInitializer__5fc_H_
#define _JC_polyglot_ext_jl_types_LazyClassInitializer__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_types_ParsedClassType$object;
struct _jc_polyglot_types_TypeSystem$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$sub_refs	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$sub_nonrefs	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$refs	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$refs;
typedef struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$nonrefs	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object;

typedef const struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vmethods	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtable	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtype	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method$_init$964314195388e7c0(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method$fromClassFile$b6d3a7cd18d8b3b3(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *);
extern void _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method$initConstructors$f12b837fb17d9946(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *);
extern void _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method$initFields$4dd3b051288bcd17(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *);
extern void _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method$initInterfaces$314e6a4b7be97f5a(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *);
extern void _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method$initMemberClasses$82df0e8929eff4ca(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *);
extern void _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method$initMethods$aeac7ab0247cf809(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method_info$fromClassFile$b6d3a7cd18d8b3b3;
extern _jc_method _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method_info$initConstructors$f12b837fb17d9946;
extern _jc_method _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method_info$initFields$4dd3b051288bcd17;
extern _jc_method _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method_info$initInterfaces$314e6a4b7be97f5a;
extern _jc_method _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method_info$initMemberClasses$82df0e8929eff4ca;
extern _jc_method _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method_info$initMethods$aeac7ab0247cf809;

// Virtual methods structure
struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vmethods {
	jboolean	(*fromClassFile$b6d3a7cd18d8b3b3)(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *);
	void	(*initConstructors$f12b837fb17d9946)(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *);
	void	(*initFields$4dd3b051288bcd17)(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *);
	void	(*initInterfaces$314e6a4b7be97f5a)(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *);
	void	(*initMemberClasses$82df0e8929eff4ca)(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *);
	void	(*initMethods$aeac7ab0247cf809)(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *);
};

// Vtable
struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vmethods	polyglot_ext_jl_types_LazyClassInitializer__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$sub_refs {
	struct _jc_object	*ts;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$refs {
    _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$sub_refs	polyglot_ext_jl_types_LazyClassInitializer__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$sub_nonrefs	polyglot_ext_jl_types_LazyClassInitializer__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object {
	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtype _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_types_LazyClassInitializer__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_types_LazyClassInitializer__5fc_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/types/LazyClassInitializer__5fc.h <==
// public class polyglot.ext.jl.types.LazyClassInitializer_c

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c5e1cf6a6694b02b polyglot_ext_jl_types_LazyClassInitializer__5fc

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_jl_types_LazyClassInitializer__5fc_H_
#define _JC_polyglot_ext_jl_types_LazyClassInitializer__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_types_ParsedClassType$object;
struct _jc_polyglot_types_TypeSystem$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$sub_refs	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$sub_nonrefs	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$refs	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$refs;
typedef struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$nonrefs	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object;

typedef const struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vmethods	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtable	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtype	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method$_init$964314195388e7c0(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method$fromClassFile$b6d3a7cd18d8b3b3(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method$initConstructors$f12b837fb17d9946(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method$initFields$4dd3b051288bcd17(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method$initInterfaces$314e6a4b7be97f5a(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method$initMemberClasses$82df0e8929eff4ca(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method$initMethods$aeac7ab0247cf809(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method_info$fromClassFile$b6d3a7cd18d8b3b3;
extern _jc_method _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method_info$initConstructors$f12b837fb17d9946;
extern _jc_method _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method_info$initFields$4dd3b051288bcd17;
extern _jc_method _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method_info$initInterfaces$314e6a4b7be97f5a;
extern _jc_method _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method_info$initMemberClasses$82df0e8929eff4ca;
extern _jc_method _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$method_info$initMethods$aeac7ab0247cf809;

// Virtual methods structure
struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vmethods {
	jboolean	(*fromClassFile$b6d3a7cd18d8b3b3)(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *) _JC_JCNI_ATTR;
	void	(*initConstructors$f12b837fb17d9946)(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*initFields$4dd3b051288bcd17)(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*initInterfaces$314e6a4b7be97f5a)(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*initMemberClasses$82df0e8929eff4ca)(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*initMethods$aeac7ab0247cf809)(_jc_env *, struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vmethods	polyglot_ext_jl_types_LazyClassInitializer__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$sub_refs {
	struct _jc_object	*ts;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$refs {
    _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$sub_refs	polyglot_ext_jl_types_LazyClassInitializer__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$sub_nonrefs	polyglot_ext_jl_types_LazyClassInitializer__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$object {
	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$vtype _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_types_LazyClassInitializer__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_types_LazyClassInitializer__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_types_LazyClassInitializer__5fc_H_ */
